"""
Contains utils and functions for python-getenvpass module
"""
from getpass import getpass
import os


def get_env_pass(env_var=''):
    """
    Retrieves environment variable. If does not exist, run getpass module

    Returns:
        Environment variable value or getpass.

    """
    return os.environ[env_var] if env_var in os.environ else getpass()



"""
This is the setup file for installing get_env_pass

Example:
    - python setup.py install
"""
from setuptools import setup

setup(name='get_env_pass',
      version='1.0.1',
      description='get-env-pass python package',
      long_description='get-env-pass python package',
      url='https://github.com/ccavales3/python-getenvpass',
      author='Caesar Cavales',
      author_email='c.cavales3@gmail.com',
      license='MIT',
      packages=['get_env_pass'],
      zip_safe=False)
